@@ -38,7 +38,7 @@ class SandboxApi(SandboxApiBase):
         """
         List all running sandboxes.
 
-        :param api_key: API key to use for authentication, defaults to `E2B_API_KEY` environment variable
+        :param api_key: API key to use for authentication, defaults to `AGENTBOX_API_KEY` environment variable
         :param query: Filter the list of sandboxes, e.g. by metadata `SandboxQuery(metadata={"key": "value"})`, if there are multiple filters they are combined with AND.
         :param domain: Domain to use for the request, only relevant for self-hosted environments
         :param debug: Enable debug mode, all requested are then sent to localhost
@@ -116,9 +116,9 @@ class SandboxApi(SandboxApiBase):
         """
         Get the sandbox info.
         :param sandbox_id: Sandbox ID
-        :param api_key: API key to use for authentication, defaults to `E2B_API_KEY` environment variable
-        :param domain: Domain to use for the request, defaults to `E2B_DOMAIN` environment variable
-        :param debug: Debug mode, defaults to `E2B_DEBUG` environment variable
+        :param api_key: API key to use for authentication, defaults to `AGENTBOX_API_KEY` environment variable
+        :param domain: Domain to use for the request, defaults to `AGENTBOX_DOMAIN` environment variable
+        :param debug: Debug mode, defaults to `AGENTBOX_DEBUG` environment variable
         :param request_timeout: Timeout for the request in **seconds**
         :param headers: Additional headers to send with the request
         :param proxy: Proxy to use for the request
@@ -179,9 +179,9 @@ class SandboxApi(SandboxApiBase):
         """
         Get the sandbox instance number.
         :param sandbox_id: Sandbox ID
-        :param api_key: API key to use for authentication, defaults to `E2B_API_KEY` environment variable
-        :param domain: Domain to use for the request, defaults to `E2B_DOMAIN` environment variable
-        :param debug: Debug mode, defaults to `E2B_DEBUG` environment variable
+        :param api_key: API key to use for authentication, defaults to `AGENTBOX_API_KEY` environment variable
+        :param domain: Domain to use for the request, defaults to `AGENTBOX_DOMAIN` environment variable
+        :param debug: Debug mode, defaults to `AGENTBOX_DEBUG` environment variable
         :param request_timeout: Timeout for the request in **seconds**
         :param headers: Additional headers to send with the request
         :param proxy: Proxy to use for the request
@@ -229,9 +229,9 @@ class SandboxApi(SandboxApiBase):
         """
         Get the sandbox instance auth info(userId, instanceNo, accessKey, accessSecretKey, expireTime).
         :param sandbox_id: Sandbox ID
-        :param api_key: API key to use for authentication, defaults to `E2B_API_KEY` environment variable
-        :param domain: Domain to use for the request, defaults to `E2B_DOMAIN` environment variable
-        :param debug: Debug mode, defaults to `E2B_DEBUG` environment variable
+        :param api_key: API key to use for authentication, defaults to `AGENTBOX_API_KEY` environment variable
+        :param domain: Domain to use for the request, defaults to `AGENTBOX_DOMAIN` environment variable
+        :param debug: Debug mode, defaults to `AGENTBOX_DEBUG` environment variable
         :param request_timeout: Timeout for the request in **seconds**
         :param headers: Additional headers to send with the request
 
@@ -279,9 +279,9 @@ class SandboxApi(SandboxApiBase):
         """
         Get the sandbox ADB information.
         :param sandbox_id: Sandbox ID
-        :param api_key: API key to use for authentication, defaults to `E2B_API_KEY` environment variable
-        :param domain: Domain to use for the request, defaults to `E2B_DOMAIN` environment variable
-        :param debug: Debug mode, defaults to `E2B_DEBUG` environment variable
+        :param api_key: API key to use for authentication, defaults to `AGENTBOX_API_KEY` environment variable
+        :param domain: Domain to use for the request, defaults to `AGENTBOX_DOMAIN` environment variable
+        :param debug: Debug mode, defaults to `AGENTBOX_DEBUG` environment variable
         :param request_timeout: Timeout for the request in **seconds**
         :param headers: Additional headers to send with the request
         :param proxy: Proxy to use for the request
@@ -328,9 +328,9 @@ class SandboxApi(SandboxApiBase):
         """
         Get the sandbox SSH information.
         :param sandbox_id: Sandbox ID
-        :param api_key: API key to use for authentication, defaults to `E2B_API_KEY` environment variable
-        :param domain: Domain to use for the request, defaults to `E2B_DOMAIN` environment variable
-        :param debug: Debug mode, defaults to `E2B_DEBUG` environment variable
+        :param api_key: API key to use for authentication, defaults to `AGENTBOX_API_KEY` environment variable
+        :param domain: Domain to use for the request, defaults to `AGENTBOX_DOMAIN` environment variable
+        :param debug: Debug mode, defaults to `AGENTBOX_DEBUG` environment variable
         :param request_timeout: Timeout for the request in **seconds**
         :param headers: Additional headers to send with the request
         :param proxy: Proxy to use for the request
